@@ -3,13 +3,14 @@ package App::Midgen::Role::Attributes;
 use v5.10;
 use Types::Standard qw( ArrayRef Bool Int Object Str);
 use Moo::Role;
-# use MooX::Types::MooseLike::Base qw(:all);
-use Data::Printer { caller_info => 1, colored => 1, };
+requires qw( experimental format );
+
+# use Data::Printer { caller_info => 1, colored => 1, };
 
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.24';
+our $VERSION = '0.26';
 use Carp;
 
 #######
@@ -26,7 +27,7 @@ has 'develop' => (
 sub _develop {
 	my $self = shift;
 
-	if ( $self->experimental && $self->format eq 'cpanfile' ) {
+	if ( $self->experimental && ( $self->format =~ m/cpanfile|metajson/) ) {
 		return 1;
 	} else {
 		return 0;
@@ -34,13 +35,13 @@ sub _develop {
 }
 
 has 'distribution_name' => (
-	is   => 'rw',
+	is   => 'rwp',
 	isa  => Str,
 	lazy => 1,
 );
 
 has 'found_twins' => (
-	is      => 'rw',
+	is      => 'rwp',
 	isa     => Bool,
 	lazy    => 1,
 	default => sub {
@@ -49,7 +50,7 @@ has 'found_twins' => (
 );
 
 has 'numify' => (
-	is      => 'rw',
+	is      => 'ro',
 	isa     => Bool,
 	default => sub {0},
 	lazy    => 1,
@@ -63,13 +64,13 @@ has 'package_names' => (
 );
 
 has 'ppi_document' => (
-	is   => 'rw',
+	is   => 'rwp',
 	isa  => Object,
 	lazy => 1,
 );
 
 has 'xtest' => (
-	is      => 'rw',
+	is      => 'rwp',
 	isa     => Str,
 	lazy    => 1,
 	default => sub {
@@ -77,6 +78,13 @@ has 'xtest' => (
 	},
 );
 
+has 'looking_infile' => (
+	is      => 'rwp',
+	isa     => Str,
+	lazy    => 1,
+	default => sub { },
+);
+
 no Moo::Role;
 
 1;
@@ -93,7 +101,7 @@ App::Midgen::Role::Attributes - Package Attributes used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.24
+version: 0.26
 
 =head1 METHODS
 
