@@ -7,7 +7,7 @@ use Moo::Role;
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.24';
+our $VERSION = '0.26';
 use Carp;
 
 #######
@@ -45,7 +45,16 @@ has 'experimental' => (
 has 'format' => (
 	is  => 'ro',
 	isa => sub {
-		my $format = { dsl => 1, mi => 1, mb => 1, dzil => 1, dist => 1, cpanfile => 1, };
+		my $format = {
+			dsl      => 1,
+			mi       => 1,
+			mb       => 1,
+			dzil     => 1,
+			dist     => 1,
+			cpanfile => 1,
+			metajson => 1,
+			infile   => 1
+		};
 		croak 'not a supported output format' unless defined $format->{ $_[0] };
 		return;
 	},
@@ -79,13 +88,16 @@ around [qw( debug verbose )] => sub {
 	my $self    = shift;
 	my $content = $self->$orig(@_);
 
-	if ( $self->quiet == 1 && $self->experimental == 1 ) {
+	if (   ( $self->quiet == 1 && $self->experimental == 1 )
+		|| ( $self->format eq 'infile' ) )
+	{
 		return 0;
 	} else {
 		return $content;
 	}
 };
 
+
 no Moo::Role;
 
 1;
@@ -102,7 +114,7 @@ App::Midgen::Role::Options - Package Options used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.24
+version: 0.26
 
 =head1 METHODS
 
