@@ -9,7 +9,7 @@ no if $] > 5.017010, warnings => 'experimental::smartmatch';
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.24';
+our $VERSION = '0.26';
 use English qw( -no_match_vars ); # Avoids reg-ex performance penalty
 local $OUTPUT_AUTOFLUSH = 1;
 
@@ -96,11 +96,12 @@ __END__
 
 =head1 NAME
 
-App::Midgen::Role::Output::MB - A collection of output orientated methods used by L<App::Midgen>
+App::Midgen::Role::Output::MB - Output Format - Module::Build,
+used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.24
+version: 0.26
 
 =head1 DESCRIPTION
 
