@@ -2,13 +2,15 @@ package App::Midgen::Role::UseOk;
 
 use v5.10;
 use Moo::Role;
+requires qw( ppi_document debug format xtest _process_found_modules develop );
+
 use PPI;
 use Data::Printer { caller_info => 1, colored => 1, };
 
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.24';
+our $VERSION = '0.26';
 use constant { BLANK => q{ }, NONE => q{}, TWO => 2, THREE => 3, };
 
 
@@ -71,7 +73,7 @@ sub xtests_use_ok {
 												$module =~ s/^['|"]//;
 												$module =~ s/['|"]$//;
 												if ( $module =~ m/\A[A-Z]/ ) {
-													say 'found module - ' . $module if $self->debug;
+													warn 'found module - ' . $module if $self->debug;
 													push @modules, $module;
 												}
 
@@ -111,9 +113,7 @@ sub xtests_use_ok {
 	# if we found a module, process it with the correct catogery
 	if ( scalar @modules > 0 ) {
 
-		if ( $self->format eq 'cpanfile' ) {
-			# $self->xtest eq 'test_requires' -> t/
-			# $self->xtest eq 'test_develop' -> xt/
+		if ( $self->format =~ /cpanfile|metajson/ ) {
 			if ( $self->xtest eq 'test_requires' ) {
 				$self->_process_found_modules( 'test_requires', \@modules );
 			} elsif ( $self->develop && $self->xtest eq 'test_develop' ) {
@@ -143,7 +143,7 @@ for methods in use_ok in BEGIN blocks, used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.24
+version: 0.26
 
 =head1 METHODS
 
